##  Rename Three Existing Fact Sheet Types
A few of the existing Fact Sheet types need to be renamed to align with Meta Model v4.
They are:
  * User Group → Organization
  * Project → Initiative
  * Process → Business Context


**Note**
Renaming happens in the translations of the Fact Sheet. Therefore, there will be no impact on the existing integrations.
To rename the Fact Sheet types, follow these steps:
  1. Navigate to Administration > Meta Model Configuration, and choose the Fact Sheet type you want to rename.
  2. Click Edit at the top right corner of the page to reveal the right-side panel.
  3. On the right-side panel, click on the Manage Translation tab indicated with the globe icon.
  4. Depending on the Fact Sheet that is being renamed, fill in the following values in the Singular and Plural fields. Also, add Help text for better context.
|  User Group |  Project  | Process
---|---|---|---
Help text (Optional): | Who is using which Application, how many users are using an Application? | Which Initiatives are currently changing the IT landscape? | Which Business Contexts are affecting the IT landscape?
Singular: | Organization | Initiative | Business Context
Plural: | Organizations | Initiatives | Business Contexts


  5. Click Show changes, and then Apply. The Fact Sheet type is renamed.
![Renaming existing Fact Sheet type](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2749442f7a4410148273d7a1dd097ad7_LowRes.gif)
Renaming existing Fact Sheet type
